==> substance_4.1.orig.tar.gz: substance-4.1.orig/src/test/samples/substance/clientprop/CornerRadius.java <==
/*
 * Copyright (c) 2005-2007 Substance Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of Substance Kirill Grouchnikov nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package test.samples.substance.clientprop;

import java.awt.BorderLayout;

import javax.swing.*;

import org.jvnet.substance.SubstanceLookAndFeel;

/**
 * Test application that shows the use of the
 * {@link SubstanceLookAndFeel#CORNER_RADIUS} client property.
 * 
 * @author Kirill Grouchnikov
 * @see SubstanceLookAndFeel#CORNER_RADIUS
 */
public class CornerRadius extends JFrame {
	/**
	 * Creates the main frame for <code>this</code> sample.
	 */
	public CornerRadius() {
		super("Toolbar button corner radius");

		this.setLayout(new BorderLayout());
		
		JToolBar toolBar = new JToolBar("");
		toolBar.add(new JLabel("Sample toolbar"));
		toolBar.add(new JSeparator(SwingConstants.VERTICAL));

		JToggleButton buttonDefault = new JToggleButton("radius default");
		buttonDefault.setSelected(true);
		toolBar.add(buttonDefault);

		JToggleButton button1 = new JToggleButton("radius 5");
		// set corner radius to 5 pixels
		button1.putClientProperty(SubstanceLookAndFeel.CORNER_RADIUS, Float
				.valueOf(5.0f));
		button1.setSelected(true);
		toolBar.add(button1);
		
		JToggleButton button2 = new JToggleButton("radius 0");
		// set corner radius to 0 pixels (perfect rectangle)
		button2.putClientProperty(SubstanceLookAndFeel.CORNER_RADIUS, Float
				.valueOf(0.0f));
		button2.setSelected(true);
		toolBar.add(button2);

		this.add(toolBar, BorderLayout.NORTH);
		
		this.setSize(400, 200);
		this.setLocationRelativeTo(null);
		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	}

	/**
	 * The main method for <code>this</code> sample. The arguments are
	 * ignored.
	 * 
	 * @param args
	 *            Ignored.
	 * @throws Exception
	 *             If some exception occured. Note that there is no special
	 *             treatment of exception conditions in <code>this</code>
	 *             sample code.
	 */
	public static void main(String[] args) throws Exception {
		UIManager.setLookAndFeel(new SubstanceLookAndFeel());
		JFrame.setDefaultLookAndFeelDecorated(true);
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				new CornerRadius().setVisible(true);
			}
		});
	}
}

==> substance_5.2.orig.tar.gz: substance-5.2.orig/src/test/samples/substance/clientprop/CornerRadius.java <==
/*
 * Copyright (c) 2005-2008 Substance Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of Substance Kirill Grouchnikov nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package test.samples.substance.clientprop;

import java.awt.BorderLayout;

import javax.swing.*;

import org.jvnet.substance.SubstanceLookAndFeel;
import org.jvnet.substance.skin.SubstanceBusinessBlackSteelLookAndFeel;

/**
 * Test application that shows the use of the
 * {@link SubstanceLookAndFeel#CORNER_RADIUS} client property.
 * 
 * @author Kirill Grouchnikov
 * @see SubstanceLookAndFeel#CORNER_RADIUS
 */
public class CornerRadius extends JFrame {
	/**
	 * Creates the main frame for <code>this</code> sample.
	 */
	public CornerRadius() {
		super("Toolbar button corner radius");

		this.setLayout(new BorderLayout());
		
		JToolBar toolBar = new JToolBar("");
		toolBar.add(new JLabel("Sample toolbar"));
		toolBar.add(new JSeparator(SwingConstants.VERTICAL));

		JToggleButton buttonDefault = new JToggleButton("radius default");
		buttonDefault.setSelected(true);
		toolBar.add(buttonDefault);

		JToggleButton button1 = new JToggleButton("radius 5");
		// set corner radius to 5 pixels
		button1.putClientProperty(SubstanceLookAndFeel.CORNER_RADIUS, Float
				.valueOf(5.0f));
		button1.setSelected(true);
		toolBar.add(button1);
		
		JToggleButton button2 = new JToggleButton("radius 0");
		// set corner radius to 0 pixels (perfect rectangle)
		button2.putClientProperty(SubstanceLookAndFeel.CORNER_RADIUS, Float
				.valueOf(0.0f));
		button2.setSelected(true);
		toolBar.add(button2);

		this.add(toolBar, BorderLayout.NORTH);
		
		this.setSize(400, 200);
		this.setLocationRelativeTo(null);
		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	}

	/**
	 * The main method for <code>this</code> sample. The arguments are
	 * ignored.
	 * 
	 * @param args
	 *            Ignored.
	 * @throws Exception
	 *             If some exception occured. Note that there is no special
	 *             treatment of exception conditions in <code>this</code>
	 *             sample code.
	 */
	public static void main(String[] args) throws Exception {
		UIManager.setLookAndFeel(new SubstanceBusinessBlackSteelLookAndFeel());
		JFrame.setDefaultLookAndFeelDecorated(true);
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				new CornerRadius().setVisible(true);
			}
		});
	}
}
